@@ -1,16 +1,15 @@
 from typing import List
 from typing import Optional
 
-from overrides import overrides
-
-from konoha.word_tokenizer import WordTokenizer
-
 try:
     from allennlp.data.tokenizers.token import Token
     from allennlp.data.tokenizers.tokenizer import Tokenizer
 except ImportError:
+    from konoha.integrations._allennlp import Token
     from konoha.integrations._allennlp import Tokenizer
-    Token = None
+from overrides import overrides
+
+from konoha.word_tokenizer import WordTokenizer
 
 
 @Tokenizer.register("konoha")
@@ -20,7 +19,7 @@ class KonohaTokenizer(Tokenizer):
 
     def __init__(
         self,
-        tokenizer_name: str = 'mecab',
+        tokenizer_name: str = "mecab",
         with_postag: bool = False,
         user_dictionary_path: Optional[str] = None,
         system_dictionary_path: Optional[str] = None,
@@ -41,7 +40,6 @@ class KonohaTokenizer(Tokenizer):
         )
         self._start_tokens = start_tokens or []
         self._start_tokens.reverse()
-
         self._end_tokens = end_tokens or []
 
     @overrides
@@ -52,11 +50,7 @@ class KonohaTokenizer(Tokenizer):
     def tokenize(self, text: str) -> List[Token]:
         konoha_tokens = self._tokenizer.tokenize(text)
         tokens = [
-            Token(
-                text=token.surface,
-                lemma_=token.base_form,
-                pos_=token.postag,
-            )
+            Token(text=token.surface, lemma_=token.base_form, pos_=token.postag,)
             for token in konoha_tokens
         ]
 
