@@ -1,6 +1,7 @@
+from typing import List
 from typing import Optional
 
-from konoha.konoha_token import Token
+from konoha.data.token import Token
 from konoha.word_tokenizers.tokenizer import BaseTokenizer
 
 
@@ -9,7 +10,7 @@ class KyTeaTokenizer(BaseTokenizer):
 
     def __init__(
         self, with_postag: bool = False, model_path: Optional[str] = None, **kwargs
-    ):
+    ) -> None:
 
         super(KyTeaTokenizer, self).__init__(
             name="kytea", with_postag=with_postag, model_path=model_path
@@ -25,13 +26,13 @@ class KyTeaTokenizer(BaseTokenizer):
         kytea_option = ""
         if model_path is not None:
             kytea_option += "-model {}".format(model_path)
-        self.kytea = Mykytea.Mykytea(kytea_option)
+        self._tokenizer = Mykytea.Mykytea(kytea_option)
 
-    def tokenize(self, text: str):
+    def tokenize(self, text: str) -> List[Token]:
         tokens = []
 
-        if self.with_postag:
-            response = self.kytea.getTagsToString(text)
+        if self._with_postag:
+            response = self._tokenizer.getTagsToString(text)
 
             # FIXME Following dirty workaround is required to
             #       process inputs which include <whitespace> itself
@@ -49,7 +50,7 @@ class KyTeaTokenizer(BaseTokenizer):
                 tokens.append(Token(surface=surface, postag=postag, pron=pron))
 
         else:
-            for surface in list(self.kytea.getWS(text)):
+            for surface in list(self._tokenizer.getWS(text)):
                 tokens.append(Token(surface=surface))
 
         return tokens
